import { useAjax } from '@/Hook/useAjax';
import {
  apiDistributorAccount,
  apiDistributorAccountInfoRemove,
  apiDistributorAccountList,
  apiDistributorAccountPageList,
  apiDistributorAccountUpdate,
  apiDistributorAccountUpdateEnabled,
} from '@/services/distribution/accountInfo';
import { apiDistributorInfoList } from '@/services/distribution/info';
import { PlusCircleOutlined } from '@ant-design/icons';
import { ActionType, BetaSchemaForm, ProFormInstance, ProTable } from '@ant-design/pro-components';
import { Button, Drawer, message } from 'antd';
import { useRef, useState } from 'react';
import { itemFormConfig } from './formConfig';
import { itemColumns } from './tableConfig';
type DataItem = {
  name: string;
  state: string;
};
type Props = {
  data: any;
  onClose: (v: any) => void;
};
const Page: React.FC<Props> = (props) => {
  let { data, onClose } = props;
  let [open, setOpen] = useState<any>(null); //新建弹窗
  const [uploadOpen, setUploadOpen] = useState(false);
  let [editValues, setEditValues] = useState<any>({});
  // ======================API=======================
  let DistributorInfoList = useAjax((params) => apiDistributorInfoList(params)); //分销商列表
  let DistributorAccountUpdate = useAjax((params) => apiDistributorAccountUpdate(params)); //修改
  let DistributorAccount = useAjax((params) => apiDistributorAccount(params)); //新增
  let DistributorAccountPageList = useAjax((params) => apiDistributorAccountPageList(params), {
    type: 'table',
  }); //分销商账号分页列表
  let DistributorAccountList = useAjax((distributorId) => apiDistributorAccountList(distributorId)); //分销商账号全部列表
  let DistributorAccountInfoRemove = useAjax((distributorId) =>
    apiDistributorAccountInfoRemove(distributorId),
  ); //分销商账号删除
  let DistributorAccountUpdateEnabled = useAjax((distributorId) =>
    apiDistributorAccountUpdateEnabled(distributorId),
  ); //分销商账号状态更新
  const formRef = useRef<ProFormInstance>();
  const actionRef = useRef<ActionType>();
  // // 起始获取列表
  // useEffect(() => {
  //     DistributorInfoList.run()
  // }, [])
  // 删除or批量删除
  const del = (id: any) => {
    DistributorAccountInfoRemove.run(id).then((res) => {
      if (res.code === 200) {
        actionRef?.current?.reload();
        message.success('删除成功');
      }
    });
  };
  // 状态更新
  const stateUpdata = (id: any, ck: boolean) => {
    return DistributorAccountUpdateEnabled.run({ id, enabled: ck }).then((res) => {
      if (res.data) {
        actionRef?.current?.reload();
        message.success(ck ? '启动成功' : '停用成功');
      }
      return true;
    });
  };
  // 提交表单
  const submit = async (values: any) => {
    let api = editValues?.id ? DistributorAccountUpdate : DistributorAccount;
    if (editValues?.id) {
      values.id = editValues?.id;
    }
    values.distributorId = data.id;
    if (!values.subAccountList) {
      values.subAccountList = [];
    }
    api.run(values).then((res) => {
      if (res.code === 200) {
        actionRef?.current?.reload();
        message.success('操作成功!');
        closeForm(false);
      }
    });
  };
  // 关闭表单弹窗和重置表单内容
  const closeForm = (b: boolean, values?: any) => {
    if (!b) {
      setEditValues({});
      formRef?.current?.resetFields?.();
      setOpen(b);
    } else {
      DistributorAccountList.run(data.id);
      setEditValues(values);
      setTimeout(() => {
        formRef.current?.setFieldsValue({
          ...values,
          subAccountList: values?.subDistributorAccountList?.map((item: { id: any }) => item.id),
        });
      }, 100);
      setOpen(b);
    }
  };

  return (
    <Drawer
      open={data?.id}
      placement="right"
      onClose={() => {
        onClose({});
      }}
      width={'75%'}
      footer={null}
      destroyOnClose={true}
      closeIcon={false}
    >
      <ProTable<any, any>
        headerTitle={'《' + data?.companyName + '》账号列表'}
        actionRef={actionRef}
        rowKey={(r) => r.id}
        search={{
          labelWidth: 120,
        }}
        scroll={{ x: 'auto' }}
        params={{ distributorId: data?.id }}
        request={async (params) => {
          if (params.distributorId) {
            return await DistributorAccountPageList.run(params);
          }
        }}
        toolBarRender={() => {
          return [
            <Button
              type="primary"
              onClick={() => {
                DistributorAccountList.run(data.id);
                setOpen(true);
              }}
            >
              <PlusCircleOutlined />
              新增分销账号
            </Button>,
          ];
        }}
        columns={itemColumns({ del, closeForm, stateUpdata })}
        loading={DistributorAccountPageList?.loading || DistributorAccountUpdateEnabled?.loading}
      />
      {/* 新增段落 */}
      <BetaSchemaForm<DataItem>
        layout="horizontal"
        title={!editValues?.id ? '新增分销账号' : '编辑分销账号'}
        formRef={formRef}
        open={open}
        onOpenChange={(b) => {
          !b && closeForm(b);
        }}
        layoutType={'ModalForm'}
        grid={true}
        labelCol={{ span: 6 }}
        colProps={{ span: 20 }}
        width={500}
        onFinish={submit}
        columns={itemFormConfig(DistributorAccountList?.data?.data, !!editValues?.id)}
        loading={DistributorAccount?.loading || DistributorAccountUpdate?.loading}
      />
    </Drawer>
  );
};
export default Page;
