import { useAjax } from '@/Hook/useAjax';
import {
  ActionType,
  BetaSchemaForm,
  ProFormInstance,
  ProTable,
} from '@ant-design/pro-components';
import { useModel } from '@umijs/max';
import { Button, message } from 'antd';
import { forwardRef, useEffect, useImperativeHandle, useRef, useState } from 'react';
import formConfig from './formConfig';
import { columns } from './tableConfig';
import { apiMiniappComponentInfoDel, apiMiniappComponentInfoPageList, apiMiniappComponentInfoSave, apiMiniappComponentInfoUpdate, apiMiniappComponentInfoUpdateEnabled } from '@/services/distribution/miniprogram';

type DataItem = {
  name: string;
  state: string;
};
const Page = forwardRef((props: any, ref?: any) =>{
  let { data,reload } = props
  const formRef = useRef<ProFormInstance>();
  const actionRef = useRef<ActionType>();
  let { state } = useModel('global');
  let [open, setOpen] = useState<any>(null); //新增 存在ID代表是当前模板页面
  let [editValues, setEditValues] = useState<any>({});
  // ======API===============
  let MiniappComponentInfoPageList = useAjax((params) => apiMiniappComponentInfoPageList(params), { type: 'table' }); //列表
  let MiniappComponentInfoUpdate = useAjax((params) => apiMiniappComponentInfoUpdate(params)); //更新
  let MiniappComponentInfoSave = useAjax((params) => apiMiniappComponentInfoSave(params)); //新增
  let MiniappComponentInfoDel = useAjax((params) => apiMiniappComponentInfoDel(params)); //删除
  let MiniappComponentInfoUpdateEnabled = useAjax((params) => apiMiniappComponentInfoUpdateEnabled(params)); //启停

  useEffect(() => {
  }, []);
  // 删除
  const del = (id: any) => {
    MiniappComponentInfoDel.run(id).then((res) => {
      if (res.code === 200) {
        reload()
        message.success('删除成功');
      }
    });
  };
  // 状态更新
  const stateUpdata = (id: any, ck: boolean) => {
    MiniappComponentInfoUpdateEnabled.run({ id, enabled: ck }).then((res) => {
      if (res.data) {
        reload()
        message.success(ck ? '启动成功' : '停用成功');
      }
    });
  };
  // 新增 or 编辑
  const submit = async (values: any) => {
    let api = editValues?.id ? MiniappComponentInfoUpdate : MiniappComponentInfoSave;
    if (editValues?.id) {
      values.id = editValues?.id;
      values.enabledAppPageId = editValues?.enabledAppPageId
    }else{
      values.enabledAppPageId = open
    }

    api.run(values).then((res) => {
      if (res.code === 200) {
        reload()
        message.success('操作成功!');
        closeForm(false);
      }
    });
    console.log(values);
  };
  // 关闭表单弹窗和重置表单内容
  const closeForm = (b: boolean, values?: any) => {
    if (!b) {
      setEditValues({});
      formRef?.current?.resetFields?.();
      setOpen(b);
    } else {
      setEditValues(values);
      setTimeout(() => {
        formRef?.current?.setFieldsValue({ ...values, mchId: values?.mchInfo?.id });
      }, 100);
      setOpen(b);
    }
  };
  useImperativeHandle(ref, () => ({
    openMoadl:(id:any)=>{
      setOpen(id)
    }
  }));
  console.log("open",open)
  return (
    <div >
      <ProTable<any, any>
        headerTitle={false}
        actionRef={actionRef}
        rowKey={(r) => r.id}
        search={false}
        scroll={{ x: 'auto' }}
        dataSource={data}
        toolBarRender={false}
        columns={columns(closeForm, del, stateUpdata, state?.enumList)}
      bordered
      />
      {/* 新增修改 */}
      <BetaSchemaForm<DataItem>
        title={!editValues?.id ? '新增组件' : '编辑组件'}
        formRef={formRef}
        width={600}
        open={open}
        onOpenChange={(b) => {
          !b && closeForm(b);
        }}
        layoutType={'ModalForm'}
        labelCol={{ span: 6 }}
        wrapperCol={{ span: 14 }}
        grid={true}
        rowProps={{ gutter: [10, 10] }}
        layout="horizontal"
        onFinish={submit}
        columns={formConfig(state?.enumList)}
        loading={MiniappComponentInfoSave?.loading || MiniappComponentInfoUpdate?.loading}
      />
    </div>
  );
});
export default Page;
