import { useAjax } from '@/Hook/useAjax';
import { PlusCircleOutlined } from '@ant-design/icons';
import {
  ActionType,
  PageContainer,
  ProFormInstance,
  ProTable,
} from '@ant-design/pro-components';
import { Button, message, Modal, Table } from 'antd';
import { useRef, useState } from 'react';
import { childrenColumns, columns } from './tableConfig';
import { appPageList, configAppPages } from '@/services/distribution/pagesManage';
import FormComp from './formComp';
import MimiModule from '../mimiModule'

const Page: React.FC = () => {
  const formRef = useRef<ProFormInstance>();
  const actionRef = useRef<ActionType>();
  const tableRef = useRef<any>();
  let [open, setOpen] = useState<any>(null); //新增作者
  let [editValues, setEditValues] = useState<any>({});
  let appPageListApi = useAjax((params) => appPageList(params), { type: 'noPage' });
  let configAppPagesApi = useAjax((params) => configAppPages(params));

  // 编辑
  const edit = (item: any) => {
    setEditValues(item);
    setTimeout(() => {
      formRef?.current?.setFieldsValue({ ...item, appPageConfigDTOList: item.appPageVOList });
    }, 100);
    setOpen(true);
  };
  // 新增 or 编辑
  const submit = async () => {
    let values = await formRef.current?.validateFields()
    configAppPagesApi.run(values).then((res) => {
      if (res.code === 200) {
        actionRef?.current?.reload();
        message.success('操作成功!');
        closeForm(false);
      }
    });
  };
  // 关闭表单弹窗和重置表单内容
  const closeForm = (b: boolean, values?: any) => {
    if (!b) {
      setEditValues({});
      formRef?.current?.resetFields?.();
      setOpen(b);
    } else {
    }
  };
  // 刷新页面
  const reloadList = () => {
    actionRef?.current?.reload();
  }
  // 添加页面
  const openAdd = (id: any) => {
    tableRef?.current?.openMoadl(id)
  }
  return (
    <PageContainer>
      <ProTable<any, any>
        headerTitle={'页面模板列表'}
        actionRef={actionRef}
        rowKey={(r) => r.id}
        search={{
          labelWidth: 120,
        }}
        request={async (params) => {
          return await appPageListApi.run(params);
        }}
        scroll={{ x: 'auto' }}
        toolBarRender={() => {
          return [
            <Button
              type="primary"
              onClick={() => {
                setOpen(true);
              }}
            >
              <PlusCircleOutlined />
              新增页面模板
            </Button>,
          ];
        }}
        columns={columns(edit)}
        // 页面列表
        expandable={{
          defaultExpandedRowKeys: [0],
          rowExpandable: (record) => record?.appPageVOList?.length > 0,
          expandRowByClick: true,
          expandedRowRender: (record) => {
            return <Table
              columns={childrenColumns(openAdd)}
              dataSource={record.appPageVOList}
              rowKey={(r) => r.id}
              pagination={false}
              size='small'
              bordered
              // 页面组件列表
              expandable={{
                rowExpandable: (record) => record?.componentList?.length > 0,
                expandRowByClick: true,
                expandedRowRender: (record) => {
                  return <MimiModule data={record?.componentList} ref={tableRef} reload={reloadList} />
                }
              }}
            />
          },
        }}
      // bordered
      />
      <Modal
        title={!editValues?.templateName ? '新增页面模板' : '编辑页面模板'}
        width={"55%"}
        open={open}
        onCancel={() => { closeForm(false) }}
        loading={appPageListApi?.loading}
        onOk={submit}
      >
        <FormComp ref={formRef} />
      </Modal>
    </PageContainer>
  );
};
export default Page;
