import { ActionType, ProTable } from "@ant-design/pro-components"
import { columns } from "./tableConfig"
import { useAjax } from "@/Hook/useAjax"
import { useModel } from "@umijs/max"
import { useCallback, useRef, useState } from "react"
import { Button, Drawer, message, Modal } from "antd"
import { miniAppusers, updateEnabled } from "@/services/distribution/MiniAppUser"
type Props={
    data:{
        wechatAppId:string
        id:number
        appName:string
    }
}
const Page: React.FC<Props> = (props) => {
    const [open, setOpen] = useState(false)
    const actionRef = useRef<ActionType>();
    let { enumList } = useModel("global", (model) => ({
        enumList: model.state.enumList
    }))
    let getList = useAjax((params) => miniAppusers(params), { type: 'table' })
    let upDateApi = useAjax((params) => updateEnabled(params))

    const upDate = useCallback((params: { id: any, enabled: boolean }) => {
        upDateApi.run(params).then(res => {
            if (res.code === 200) {
                message.success("修改状态成功！")
                actionRef.current?.reload()//刷新
            }
        })
    }, [])
    return <>
        <Button
            size="small"
            type="link"
            onClick={()=>{setOpen(true)}}
        >用户列表</Button>
        <Drawer
            open={open}
            footer={false}
            onClose={()=>{setOpen(false)}}
            title={props?.data?.appName}
            width={"85%"}
            destroyOnClose
        >
            <ProTable<any, any>
                actionRef={actionRef}
                scroll={{ x: true }}
                headerTitle={"微信小程序用户列表"}
                rowKey={(r) => r.id}
                search={{
                    labelWidth: 120,
                }}
                params={{
                    appId:props.data.id
                }}
                request={async (params) => {
                    if (params?.appId) {
                        return await getList.run(params)
                    }
                }}
                columns={columns({ enumList: enumList || [], upDate })}
            // bordered
            />
        </Drawer>
    </>

}
export default Page